@@ -26,8 +26,8 @@ def draw1dratio(
     addinfo: str = "",
     logy: bool = False,
     output_dir: str = None
-  ) -> None:
-  """Function to draw two 1d histograms and their ratio, both including statistical uncertainties."""
+  ) -> str:
+  """Function to draw two 1d histograms and their ratio, both including statistical uncertainties. Returns location of saved plot."""
   
   # Replace x-axis label by nice string if custom xlab is not provided:
   xlab = utils.getnicestr(x) if xlab == None else xlab
