@@ -36,8 +36,8 @@ def draw2dplot(
     output_dir: str = None,
     addnumbers: bool = False,
     doballs: bool = False
-  ) -> None:
-  """Function to draw a 2D histogram of x vs y."""
+  ) -> str:
+  """Function to draw a 2D histogram of x vs y. Returns location of saved plot."""
   # Replace x- and y-axis labels by nice strings if custom xlab and ylab are not provided:
   xlab = utils.getnicestr(x.name) if xlab == None else xlab
   ylab = utils.getnicestr(y.name) if ylab == None else ylab
